BootstrapState

Struct BootstrapState 

pub struct BootstrapState { /* private fields */ }
Bootstrap state returned after successful bootstrap.

This struct holds all runtime handles assembled during bootstrap. It does not start background loops or bind network sockets.

The concrete HTTP router and shared router state are assembled from bootstrap output (config control flag, projection state, and readiness).

Implementations

Source

impl BootstrapState

pub fn config(&self) -> &DaemonConfig

Returns the validated configuration.

pub fn metrics(&self) -> &MetricsRegistry

Returns the metrics registry handle.

pub fn http_router(&self) -> &Router

Returns the concrete HTTP router.

pub fn router_state(&self) -> &RouterState

Returns the shared router state (Arc-wrapped inner state).

pub fn clock(&self) -> &SharedDaemonClock

Returns the shared authoritative daemon clock handle.

pub fn into_http(self) -> (Router, RouterState)

Consumes self and returns the concrete router and router state as a tuple.

pub fn wal_path(&self) -> &PathBuf

Returns the WAL path.

pub fn snapshot_path(&self) -> &PathBuf

Returns the snapshot path.

pub fn projection(&self) -> &ReplayReducer

Returns the ReplayReducer projection state.

pub fn ready_status(&self) -> ReadyStatus

Returns the ready status indicating daemon readiness.