pub struct ReadyResponse {
pub status: &'static str,
}Expand description
Ready check response payload.
This struct represents the stable schema for the ready endpoint response. Fields should not be modified without careful consideration of external dependencies that may rely on this contract.
Readiness vocabulary (WP-2)
When not ready, the status should be one of the documented reasons from
ReadyStatus:
ReadyStatus::REASON_CONFIG_INVALIDReadyStatus::REASON_BOOTSTRAP_INCOMPLETE
Fields
status: &'static strDaemon readiness status.
When the daemon is fully ready, this is “ready”. When not ready, this contains a reason string.
Implementations