Module metrics

Module metrics 

Prometheus metrics surfaces for the daemon.

This module provides the daemon-scoped metrics registry and registration helpers used by the /metrics export route.

Modules

attempts
Attempt metrics population from authoritative projection.
recovery
Authoritative recovery metrics population from bootstrap observations.
registry
Prometheus metrics registry for daemon observability surfaces.
runs
Run metrics population from authoritative projection and daemon clock.
wal
Authoritative WAL append metric population from storage telemetry.