pub struct BootstrapState { /* private fields */ }Expand description
Bootstrap state returned after successful bootstrap.
This struct holds all runtime handles assembled during bootstrap. It does not start background loops or bind network sockets.
The concrete HTTP router and shared router state are assembled from bootstrap output (config control flag, projection state, and readiness).
Implementations
Sourceimpl BootstrapState
impl BootstrapState
Sourcepub fn config(&self) -> &DaemonConfig
pub fn config(&self) -> &DaemonConfig
Returns the validated configuration.
Sourcepub fn metrics(&self) -> &MetricsRegistry
pub fn metrics(&self) -> &MetricsRegistry
Returns the metrics registry handle.
Sourcepub fn http_router(&self) -> &Router
pub fn http_router(&self) -> &Router
Returns the concrete HTTP router.
Sourcepub fn router_state(&self) -> &RouterState
pub fn router_state(&self) -> &RouterState
Returns the shared router state (Arc-wrapped inner state).
Sourcepub fn clock(&self) -> &SharedDaemonClock
pub fn clock(&self) -> &SharedDaemonClock
Returns the shared authoritative daemon clock handle.
Sourcepub fn into_http(self) -> (Router, RouterState)
pub fn into_http(self) -> (Router, RouterState)
Consumes self and returns the concrete router and router state as a tuple.
Sourcepub fn snapshot_path(&self) -> &PathBuf
pub fn snapshot_path(&self) -> &PathBuf
Returns the snapshot path.
Sourcepub fn projection(&self) -> &ReplayReducer
pub fn projection(&self) -> &ReplayReducer
Returns the ReplayReducer projection state.
Sourcepub fn ready_status(&self) -> ReadyStatus
pub fn ready_status(&self) -> ReadyStatus
Returns the ready status indicating daemon readiness.